@@ -13,7 +13,7 @@ use Readonly;
 Readonly::Array our @EXPORT_OK => qw(conflict hash hash_array);
 
 # Version.
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 # Check conflits.
 sub conflict {
@@ -310,7 +310,17 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Config::Dot>.
+=over
+
+=item L<Config::Dot>
+
+Module for simple configure file parsing.
+
+=item L<Config::Dot::Array>
+
+Module for simple configure file parsing with arrays.
+
+=back
 
 =head1 AUTHOR
 
@@ -320,10 +330,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © Michal Špaček 2011-2015
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
